Api class

Constructors

Api()

Properties

hashCode int
The hash code for this object.
no setterinherited
onTokenExpired Future<void> Function()?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storage Storage
final

Methods

acceptConsent(String id) Future<void>
getConsent(String id) Future<ConsentInfo?>
getHealthConnections() Future<List<HealthConnection>>
getHealthStatuses() Future<HealthVerificationStatusesResponse?>
getPartnerHVStatus() Future<VerificationFlowResponse?>
getPartnerIDVStatus() Future<VerificationFlowResponse?>
getPartnerUserProfile() Future<UserProfile?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited