ProdConfig class

Implemented types

Constructors

ProdConfig()

Properties

baseUrl String
no setteroverride
connectedHealtProvidersPublicUrl String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
idvPublicUrl String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHealtProvidersPublicUrl String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited