Storage class
Constructors
- Storage()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → Future< void> -
getEnv(
) → Future< PlumcheckEnvironment?> -
getToken(
) → Future< String?> -
getTokenOrThrow(
) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveEnv(
PlumcheckEnvironment env) → Future< void> -
saveToken(
String token) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited