SDKException class

Implemented types

Constructors

SDKException({int? code, String? category, String? reason, required String description})
SDKException.fromJson(Map<String, dynamic> json)
factory
SDKException.withMessage(String message)
factory

Properties

category String?
final
code int?
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited