HealthConnection class

Constructors

HealthConnection({required String id, required String providerId, required String providerName, String? providerLogoUrl, required HealthConnectionState state, DateTime? lastSyncStartedAt, DateTime? lastSuccessfulSyncAt, required HealthConnectionSyncStatus syncStatus, required DateTime createdAt})
HealthConnection.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
lastSuccessfulSyncAt DateTime?
final
lastSyncStartedAt DateTime?
final
providerId String
final
providerLogoUrl String?
final
providerName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state HealthConnectionState
final
syncStatus HealthConnectionSyncStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited