UserProfile class

Constructors

UserProfile({required String id, String? email, String? phoneNumber, UserVerifiedIdentity? verifiedIdentity, required PartnerInfo partnerInfo})
UserProfile.fromJson(Map<String, dynamic> json)
factory

Properties

email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
partnerInfo PartnerInfo
final
phoneNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verifiedIdentity UserVerifiedIdentity?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited