VerificationFlowResponse class
Constructors
-
VerificationFlowResponse({required VerificationCompletionStatus status, List<
VerificationStep> ? steps}) -
VerificationFlowResponse.fromJson(Map<
String, dynamic> json) -
factory
- VerificationFlowResponse.fromString(String jsonString)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → VerificationCompletionStatus
-
final
-
steps
→ List<
VerificationStep> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited