VerificationMetadata class

Constructors

VerificationMetadata({DateTime? startedAt, DateTime? completedAt, String? consentId, String? type})
VerificationMetadata.fromJson(Map<String, dynamic> json)
factory
VerificationMetadata.fromString(String jsonString)
factory

Properties

completedAt DateTime?
final
consentId String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime?
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited