VerificationStep class

Constructors

VerificationStep({required String name, required VerificationStatus status, VerificationMetadata? metadata})
VerificationStep.fromJson(Map<String, dynamic> json)
factory
VerificationStep.fromString(String jsonString)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata VerificationMetadata?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status VerificationStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited