WidgetResult class

Constructors

WidgetResult({Map<String, dynamic>? data, String? errorMessage, int? errorCode})

Properties

data Map<String, dynamic>?
final
errorCode int?
final
errorMessage String?
final
hasData bool
no setter
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

error(String errorMessage, int errorCode) WidgetResult
success(Map<String, dynamic>? data) WidgetResult