PlumCheckSDK class

Constructors

PlumCheckSDK()
PlumCheckSDK.forTest({required Storage storage, required Api api})

Properties

api Api
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storage Storage
final
userInfo UserProfile?
getter/setter pair

Methods

acceptConsent(String id) Future<void>
getConsent(String id) Future<ConsentInfo?>
getHealthConnections() Future<List<HealthConnection>>
getHealthStatuses() Future<HealthVerificationStatusesResponse?>
getHVFlowStatus() Future<VerificationFlowResponse?>
getIDVFlowStatus() Future<VerificationFlowResponse?>
getUserProfile() Future<UserProfile?>
init({required String accessToken, required Future<String?> onTokenExpired(), PlumcheckEnvironment env = PlumcheckEnvironment.sandbox}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showIDV(BuildContext context) Future<VerificationFlowResponse?>
showManageConnections(BuildContext context) Future<void>
showSearchProviderDirectory(BuildContext context) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited